Package 'symbol.equation.gpt'

Title: Powerful User Interface to Build Equations and Add Symbols
Description: User Interface for adding symbols, smileys, arrows, building mathematical equations using 'LaTeX' or 'r2symbols'. Built for use in development of 'Markdown' and 'Shiny' Outputs.
Authors: Obinna Obianom [aut, cre]
Maintainer: Obinna Obianom <[email protected]>
License: MIT + file LICENSE
Version: 1.1.3
Built: 2026-05-24 09:59:26 UTC
Source: https://github.com/oobianom/symbol.equation.gpt

Help Index


Library initialize and path loader

Description

Initialize and load library path for package

Usage

envir.prep()

Value

library location

Examples

if(interactive()){
envir.prep()
}

Primary widget container

Description

Customizable widget opener

Usage

equationSymbol.Widget(viewer = c("pane", "dialog"))

Arguments

viewer

viewer option to open widget

Value

shiny app widget

Examples

if(interactive()){
equationSymbol.Widget()
}

Add symbol to current page

Description

Add selected symbol to page

Usage

insert.Symbol.Raw(symbolid, type = letters[1:4])

Arguments

symbolid

the symbol id to include

type

type of inclusion

Value

pastes copied symbol code into document

Examples

if(interactive()){
insert.Symbol.Raw("sample copied")
insert.Symbol.Raw("rpkg.net","a")
}

Main Widget Helper for symbols

Description

Assembles the interface for the symbols builder

Usage

symbol.equation.ui()

Value

user interface for the builder

Examples

if(interactive()){
symbol.equation.ui()
}

Main Widget Helper for symbols viewer2

Description

Assembles the interface for the symbols builder

Usage

symbol.equation.ui2()

Value

user interface for the builder in modal

Examples

if(interactive()){
symbol.equation.ui2()
}