| Title: | Powerful User Interface to Build Equations and Add Symbols |
|---|---|
| Description: | User Interface for adding symbols, smileys, arrows, building mathematical equations using 'LaTeX' or 'r2symbols'. Built for use in development of 'Markdown' and 'Shiny' Outputs. |
| Authors: | Obinna Obianom [aut, cre] |
| Maintainer: | Obinna Obianom <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 1.1.3 |
| Built: | 2026-05-24 09:59:26 UTC |
| Source: | https://github.com/oobianom/symbol.equation.gpt |
Initialize and load library path for package
envir.prep()envir.prep()
library location
if(interactive()){ envir.prep() }if(interactive()){ envir.prep() }
Customizable widget opener
equationSymbol.Widget(viewer = c("pane", "dialog"))equationSymbol.Widget(viewer = c("pane", "dialog"))
viewer |
viewer option to open widget |
shiny app widget
if(interactive()){ equationSymbol.Widget() }if(interactive()){ equationSymbol.Widget() }
Add selected symbol to page
insert.Symbol.Raw(symbolid, type = letters[1:4])insert.Symbol.Raw(symbolid, type = letters[1:4])
symbolid |
the symbol id to include |
type |
type of inclusion |
pastes copied symbol code into document
if(interactive()){ insert.Symbol.Raw("sample copied") insert.Symbol.Raw("rpkg.net","a") }if(interactive()){ insert.Symbol.Raw("sample copied") insert.Symbol.Raw("rpkg.net","a") }
Assembles the interface for the symbols builder
symbol.equation.ui()symbol.equation.ui()
user interface for the builder
if(interactive()){ symbol.equation.ui() }if(interactive()){ symbol.equation.ui() }
Assembles the interface for the symbols builder
symbol.equation.ui2()symbol.equation.ui2()
user interface for the builder in modal
if(interactive()){ symbol.equation.ui2() }if(interactive()){ symbol.equation.ui2() }